#include "lidar_lite.h"

int main(int argc, char *argv[])
{
	std::cout << "***************************************************" << std::endl;
  std::cout << "*           LIDAR LITE TEST APPLICATION           *" << std::endl;
	std::cout << "***************************************************" << std::endl;

	std::string serial = "A700evSl";

	CLidarLite* laser_ptr = new CLidarLite(serial,0);
	
	try
	{
		laser_ptr->open();
		
		// E1: Get 10 measurements with bias correction
	  std::cout << std::endl << "***** Example 1: Measurements WITH bias correction: *******" << std::endl;
		for (int ii = 0; ii < 10; ++ii)
		 	std::cout << "  - Range: " << laser_ptr->get_range(true) << " [cm]" << std::endl;
		
		// E2: New configuration mode
	  std::cout << std::endl << "***** Example 2: Set new configuration mode. **************" << std::endl;
		laser_ptr->set_new_config(5);

		// E3: Test 2: Get 10 measurements without bias correction
	  std::cout << std::endl << "***** Example 3: Measurements WITHOUT bias correction *****" << std::endl;
		for (int ii = 0; ii < 10; ++ii)
		 	std::cout << "  - Range: " << laser_ptr->get_range(false) << " [cm]" << std::endl;

		// E4: Get correlation values
	  std::cout << std::endl << "***** Example 4: Get correlation values. ******************" << std::endl;
	  int num_meas = 50;
		std::cout << " - Number of measurements to analize: " << num_meas << std::endl;
		std::vector<int> corr_val = laser_ptr->get_correlation(num_meas);
		std::cout << " - Correlation values: [";
		for (unsigned int ii = 0; ii < corr_val.size(); ++ii)
		{
			if (ii < corr_val.size()-1)
				std::cout << corr_val.at(ii) << ",";
			else
				std::cout << corr_val.at(ii);
			std::cout << std::flush;
		}
		std::cout << "]" << std::endl;
		laser_ptr->close();

		std::cout << std::endl;
  	std::cout << "***************************************************" << std::endl;
    std::cout << "*           LIDAR LITE TEST APPLICATION           *" << std::endl;
  	std::cout << "***************************************************" << std::endl;

	}catch(CLidarLiteException &e)
	{
		std::cout << e.what() << std::endl;
	}

	if(laser_ptr != NULL)
	{
		laser_ptr = NULL;
  	delete laser_ptr;
	}
}
